pub trait Dot<Rhs> {
type Output;
// Required method
fn dot(&self, rhs: &Rhs) -> Self::Output;
}Expand description
Matrix Multiplication
For two-dimensional arrays, the dot method computes the matrix multiplication.
Required Associated Types
Required Methods
Implementors
Sourceimpl Dot<AlgebraicMatrix<f64>> for AlgebraicMatrix<f64>
impl Dot<AlgebraicMatrix<f64>> for AlgebraicMatrix<f64>
type Output = AlgebraicMatrix<f64>
Sourceimpl Dot<AlgebraicMatrix<f64>> for AlgebraicMatrix<DA>
impl Dot<AlgebraicMatrix<f64>> for AlgebraicMatrix<DA>
type Output = AlgebraicMatrix<DA>
Sourceimpl Dot<AlgebraicMatrix<DA>> for AlgebraicMatrix<f64>
impl Dot<AlgebraicMatrix<DA>> for AlgebraicMatrix<f64>
type Output = AlgebraicMatrix<DA>
Sourceimpl Dot<AlgebraicMatrix<DA>> for AlgebraicMatrix<DA>
impl Dot<AlgebraicMatrix<DA>> for AlgebraicMatrix<DA>
type Output = AlgebraicMatrix<DA>
Sourceimpl Dot<AlgebraicVector<f64>> for AlgebraicMatrix<f64>
impl Dot<AlgebraicVector<f64>> for AlgebraicMatrix<f64>
type Output = AlgebraicVector<f64>
Sourceimpl Dot<AlgebraicVector<f64>> for AlgebraicMatrix<DA>
impl Dot<AlgebraicVector<f64>> for AlgebraicMatrix<DA>
type Output = AlgebraicVector<DA>
Sourceimpl Dot<AlgebraicVector<DA>> for AlgebraicMatrix<f64>
impl Dot<AlgebraicVector<DA>> for AlgebraicMatrix<f64>
type Output = AlgebraicVector<DA>
Sourceimpl Dot<AlgebraicVector<DA>> for AlgebraicMatrix<DA>
impl Dot<AlgebraicVector<DA>> for AlgebraicMatrix<DA>
type Output = AlgebraicVector<DA>
Sourceimpl<A, S, S2> Dot<ArrayBase<S2, Dim<[usize; 1]>>> for ArrayBase<S, Dim<[usize; 2]>>
Perform the matrix multiplication of the rectangular array self and
column vector rhs.
impl<A, S, S2> Dot<ArrayBase<S2, Dim<[usize; 1]>>> for ArrayBase<S, Dim<[usize; 2]>>
Perform the matrix multiplication of the rectangular array self and
column vector rhs.
The array shapes must agree in the way that
if self is M × N, then rhs is N.
Return a result array with shape M.
Panics if shapes are incompatible.