pub unsafe extern "C" fn daceWrite(
ina: *const DA,
strs: *mut c_char,
nstrs: *mut c_uint,
)Expand description
Print the DA object ina to string strs (of line length DACE_STRLEN).
Arguments
ina- Pointer to the DA object to be printedstrs- C array of size (nmmax+2)*DACE_STRLENcontaining the zero-terminated lines of lengthDACE_STRLENnstrs- Pointer where to store the final number of strings printed
The format of the output is written in DACE format which is loosely based on the format used by COSY INFINITY but is not fully compatible to it.